# SPDX-FileCopyrightText: 2025 Contributors to the OpenSTEF project <short.term.energy.forecasts@alliander.com>
#
# SPDX-License-Identifier: MPL-2.0

"""Extension points for backtesting pipeline customization.

Allows injection of custom logic at key moments during backtesting
without modifying the core simulation engine.
"""
